@@ -161,7 +161,7 @@ int Model_T::pdf(double *RsumlogPDF, double *RPDFlow, double *RPDFupp, double *R
   double int_prob = 0.0;
   double gg = contamination_strength(phi);
   double g_prob = 0.0;
-  int N_cut = N_dt;
+  int N_cut = N_dt-1;
 
   /* set value of first element for first passage time array */
   p_fpt[0][0] = tnd;
@@ -549,7 +549,7 @@ int Model_T::cdf(double *RsumlogCDF, double *RCDFlow, double *RCDFupp, double *R
   double int_prob = 0.0;
   double gg = contamination_strength(phi);
   double g_prob = 0.0;
-  int N_cut = N_dt;
+  int N_cut = N_dt-1;
 
   /* set value of first element for first passage time array */
   p_fpt[0][0] = tnd;
